/*
 * Copyright (c) 1987,1997, Prentice Hall
 * All rights reserved.
 *
 * Redistribution and use of the MINIX operating system in source and
 * binary forms, with or without modification, are permitted provided
 * that the following conditions are met:

 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.

 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.

 * - Neither the name of Prentice Hall nor the names of the software
 *   authors or contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS, AUTHORS, AND
 * CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL PRENTICE HALL OR ANY AUTHORS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
/** @addtogroup FileSystemImpl
* @{
*/ 

/**
 * @file	errno.h
 * @brief	Error codes
 */


#ifndef _ERRNO_H
#define _ERRNO_H

/* 256-512 are user error codes */
#define FS_ERROR_BASE	-256		    /**< Base for FS error codes */
#define FS_ENOENT        (FS_ERROR_BASE-1)  /**< no such file or directory */
#define FS_EIO           (FS_ERROR_BASE-2)  /**< input/output error */
#define FS_EBADF         (FS_ERROR_BASE-3)  /**< bad file descriptor */
#define FS_ENOTDIR       (FS_ERROR_BASE-4)  /**< not a directory */
#define FS_EINVAL        (FS_ERROR_BASE-5)  /**< invalid argument */
#define FS_ENFILE        (FS_ERROR_BASE-6)  /**< too many open files in system */
#define FS_EMFILE        (FS_ERROR_BASE-7)  /**< too many open files */
#define FS_EFBIG         (FS_ERROR_BASE-8)  /**< file too large */
#define FS_ENAMETOOLONG  (FS_ERROR_BASE-9)  /**< file name too long */
#define FS_ENOTEMPTY     (FS_ERROR_BASE-10)  /**< directory not empty */
#define FS_EBADCALL	 (FS_ERROR_BASE-11)  /**< out of range of filesystem's call */
#define FS_EGENERIC	 (FS_ERROR_BASE-12)  /**< other error */
#define FS_ECONNECT	 (FS_ERROR_BASE-13)  /**< new consument initiating connection error */
#define FS_ENOTCONNECT	 (FS_ERROR_BASE-14)  /**< disconnected consument tried to call some function */

#endif /* _ERRNO_H */

/**
 * }
 */
  
